declare @VWDraft_BSId uniqueidentifier,
		@VWApproved_BSId uniqueidentifier,
		@VWVersionDraft_BSId uniqueidentifier,
		@VWVersionClosed_BSId uniqueidentifier
set @VWDraft_BSId = ebs.GetBWStatusId('VWDraft', 'FTOS_BP_BankingProduct')
set @VWApproved_BSId = ebs.GetBWStatusId('VWApproved', 'FTOS_BP_BankingProduct')
set @VWVersionDraft_BSId = ebs.GetBWStatusId('VWVersion Draft', 'FTOS_BP_BankingProduct')
set @VWVersionClosed_BSId = ebs.GetBWStatusId('VWVersion Closed', 'FTOS_BP_BankingProduct')

if object_id('tempdb..#ProductsToChange','U') is not null drop table #ProductsToChange

declare @ProductMigrationStatus char(1) = '1'
select @ProductMigrationStatus = sp.ParameterValue 
from EbsMetadata.SystemParameter sp (nolock)
where sp.Name = 'ProductMigrationStatus'

update bp
set SeftBankAccountForTransactionId = (select top 1 ba.FTOS_CB_BankAccountid from ebs.FTOS_CB_BankAccount ba (nolock) where ba.Currency = bp.CurrencyId and ba.SelfBankAccount = 1 and charindex('REC',ba.AccountNo) > 0)
from ebs.FTOS_BP_BankingProduct bp
where SeftBankAccountForTransactionId is null

if @VWDraft_BSId is not null and @VWApproved_BSId is not null
begin
	if @ProductMigrationStatus = '0'
	begin
		update ebs.FTOS_BP_BankingProduct 
		set MasterAttributeId =  FTOS_BP_BankingProductid, 
			IsLastVersion = 1,
			previousBSId = null, 
			BusinessStatusId = @VWDraft_BSId
		where (MasterAttributeId is null or MasterAttributeId <> FTOS_BP_BankingProductid or previousBSId is null) 
			and ReferencedAttributeId is null
	end

	if @ProductMigrationStatus = '1'
	begin
	-- no versions
		update ebs.FTOS_BP_BankingProduct 
		set MasterAttributeId =  FTOS_BP_BankingProductid, 
			IsLastVersion = 1,
			previousBSId = @VWDraft_BSId, 
			BusinessStatusId = @VWApproved_BSId
		where (MasterAttributeId is null or MasterAttributeId <> FTOS_BP_BankingProductid or previousBSId is null) 
			and ReferencedAttributeId is null

		-- next versions (only one version draft)
		select 
			bp.FTOS_BP_BankingProductid productId_VD2A, 
			rbp.FTOS_BP_BankingProductid as productId_A2VC
		into #ProductsToChange
		from ebs.FTOS_BP_BankingProduct bp (nolock)
		join ebs.FTOS_BP_BankingProduct rbp  (nolock) on bp.ReferencedAttributeId = rbp.FTOS_BP_BankingProductid
		where bp.BusinessStatusId = @VWVersionDraft_BSId and rbp.BusinessStatusId=@VWApproved_BSId
			and isnull((select count(1) from ebs.FTOS_BP_BankingProduct c(nolock) where c.MasterAttributeId = bp.MasterAttributeId and c.BusinessStatusId = @VWVersionDraft_BSId) ,0) = 1

		if exists (select top 1 1 from #ProductsToChange)
		begin

			update bp 
			set previousBSId = @VWVersionDraft_BSId, 
				BusinessStatusId = @VWApproved_BSId
			from ebs.FTOS_BP_BankingProduct bp
			join #ProductsToChange x on bp.FTOS_BP_BankingProductid = x.productId_VD2A

			update bp 
			set previousBSId = @VWApproved_BSId, 
				BusinessStatusId = @VWVersionClosed_BSId
			from ebs.FTOS_BP_BankingProduct bp
			join #ProductsToChange x on bp.FTOS_BP_BankingProductid = x.productId_A2VC
		end
	end
end

if object_id('tempdb..#ProductsToChange','U') is not null drop table #ProductsToChange